@@ -26,7 +26,7 @@
 #include <errno.h>
 #include <unistd.h>
 
-#include "kde-qt.h"
+#include "tde-tqt.h"
 
 #include <tqaccel.h>
 #include <tqevent.h>
@@ -43,7 +43,7 @@
 #include "kchmtreeviewitem.h"
 #include "kchmsearchtoolbar.h"
 #include "kchmsettings.h"
-#include "kchmsetupdialog.h"
+#include "kchmsetupdialog_impl.h"
 #include "iconstorage.h"
 #include "kchmnavtoolbar.h"
 #include "kchmviewwindow.h"
@@ -620,7 +620,7 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 	bool do_autotest = false;
 
 #if defined (USE_KDE)
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+	TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
 
 	if ( args->isSet("autotestmode") )
 		do_autotest = true;
@@ -678,13 +678,13 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 		{
 #if defined (ENABLE_AUTOTEST_SUPPORT)
 			if ( filename.isEmpty() )
-				qFatal ("Could not use Auto Test mode without a chm file!");
+				tqFatal ("Could not use Auto Test mode without a chm file!");
 
 			m_autoteststate = STATE_INITIAL;
 			showMinimized ();
 			runAutoTest();
 #else
-			qFatal ("Auto Test mode support is not compiled in.");
+			tqFatal ("Auto Test mode support is not compiled in.");
 #endif /* defined (ENABLE_AUTOTEST_SUPPORT) */
 		}
 		return true;
@@ -705,7 +705,7 @@ void KCHMMainWindow::slotBrowserCopy( )
 
 void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
 {
-	KCHMSetupDialog dlg ( this );
+	KCHMSetupDialog_impl dlg ( this );
 	
 	// Set up the parameters
 	dlg.m_radioOnBeginOpenDialog->setChecked ( !appConfig.m_LoadLatestFileOnStartup );
@@ -731,7 +731,7 @@ void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
 
 	dlg.m_qtBrowserPath->setText ( appConfig.m_TQtBrowserPath );
 	dlg.m_radioUseQtextBrowser->setChecked ( appConfig.m_kdeUseTQTextBrowser );
-	dlg.m_radioUseKHTMLPart->setChecked ( !appConfig.m_kdeUseTQTextBrowser );
+	dlg.m_radioUseTDEHTMLPart->setChecked ( !appConfig.m_kdeUseTQTextBrowser );
 	
 	dlg.m_enableJS->setChecked ( appConfig.m_kdeEnableJS );
 	dlg.m_enablePlugins->setChecked ( appConfig.m_kdeEnablePlugins );
@@ -857,7 +857,7 @@ void KCHMMainWindow::setupSignals( )
 void KCHMMainWindow::slotHistoryMenuItemActivated( int item )
 {
 	if ( item < 0 || item >= (signed) appConfig.m_History.size() )
-		qFatal ("KCHMMainWindow::slotHistoryMenuItemActivated: bad history menu id %d", item);
+		tqFatal ("KCHMMainWindow::slotHistoryMenuItemActivated: bad history menu id %d", item);
 	
 	TQString filename = appConfig.m_History[item];
 	
@@ -1115,7 +1115,7 @@ void KCHMMainWindow::slotExtractCHM( )
 					if ( !dir.exists() )
 					{
 						if ( !dir.mkdir( dir.path() ) )
-							qWarning( "Could not create subdir %s\n", dir.path().ascii() );
+							tqWarning( "Could not create subdir %s\n", dir.path().ascii() );
 					}
 				}
 			}
@@ -1124,7 +1124,7 @@ void KCHMMainWindow::slotExtractCHM( )
 			TQFile wf( filename );
 			if ( !wf.open( IO_WriteOnly ) )
 			{
-					qWarning( "Could not write file %s\n", filename.ascii() );
+					tqWarning( "Could not write file %s\n", filename.ascii() );
 					continue;
 			}
 			
@@ -1132,7 +1132,7 @@ void KCHMMainWindow::slotExtractCHM( )
 			wf.close();
 		}
 		else
-			qWarning( "Could not get file %s\n", files[i].ascii() );
+			tqWarning( "Could not get file %s\n", files[i].ascii() );
 	}
 	
 	progress.setProgress( files.size() );
@@ -1199,7 +1199,7 @@ bool KCHMMainWindow::handleUserEvent( const KCHMUserEvent * event )
 	if ( event->m_action == "loadAndOpen" )
 	{
 		if ( event->m_args.size() != 1 && event->m_args.size() != 2 )
-			qFatal("handleUserEvent: event loadAndOpen must receive 1 or 2 args");
+			tqFatal("handleUserEvent: event loadAndOpen must receive 1 or 2 args");
 		
 		TQString chmfile = event->m_args[0];
 		TQString openurl = event->m_args.size() > 1 ? event->m_args[1] : "/";
@@ -1209,14 +1209,14 @@ bool KCHMMainWindow::handleUserEvent( const KCHMUserEvent * event )
 	else if ( event->m_action == "openPage" )
 	{
 		if ( event->m_args.size() != 1 )
-			qFatal("handleUserEvent: event openPage must receive 1 arg");
+			tqFatal("handleUserEvent: event openPage must receive 1 arg");
 		
 		return openPage( event->m_args[0] );
 	}
 	else if ( event->m_action == "findInIndex" )
 	{
 		if ( event->m_args.size() != 1 )
-			qFatal( "handleUserEvent: event searchQuery must receive 1 arg" );
+			tqFatal( "handleUserEvent: event searchQuery must receive 1 arg" );
 		
 		if ( m_tabIndexPage == -1 )
 			return false;
@@ -1228,7 +1228,7 @@ bool KCHMMainWindow::handleUserEvent( const KCHMUserEvent * event )
 	else if ( event->m_action == "searchQuery" )
 	{
 		if ( event->m_args.size() != 1 )
-			qFatal( "handleUserEvent: event searchQuery must receive 1 arg" );
+			tqFatal( "handleUserEvent: event searchQuery must receive 1 arg" );
 		
 		if ( m_tabSearchPage == -1 )
 			return false;
@@ -1238,7 +1238,7 @@ bool KCHMMainWindow::handleUserEvent( const KCHMUserEvent * event )
 		return true;
 	}
 	else
-		qWarning( "Unknown user event received: %s", event->m_action.ascii() );
+		tqWarning( "Unknown user event received: %s", event->m_action.ascii() );
 	
 	return false;
 }
